package tfc.logs

class FieldValueController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [fieldValueInstanceList: FieldValue.list(params), fieldValueInstanceTotal: FieldValue.count()]
    }

    def create = {
        def fieldValueInstance = new FieldValue()
        fieldValueInstance.properties = params
        return [fieldValueInstance: fieldValueInstance]
    }

    def save = {
        def fieldValueInstance = new FieldValue(params)
        if (fieldValueInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), fieldValueInstance.id])}"
            redirect(action: "show", id: fieldValueInstance.id)
        }
        else {
            render(view: "create", model: [fieldValueInstance: fieldValueInstance])
        }
    }

    def show = {
        def fieldValueInstance = FieldValue.get(params.id)
        if (!fieldValueInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
            redirect(action: "list")
        }
        else {
            [fieldValueInstance: fieldValueInstance]
        }
    }

    def edit = {
        def fieldValueInstance = FieldValue.get(params.id)
        if (!fieldValueInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [fieldValueInstance: fieldValueInstance]
        }
    }

    def update = {
        def fieldValueInstance = FieldValue.get(params.id)
        if (fieldValueInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (fieldValueInstance.version > version) {
                    
                    fieldValueInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'fieldValue.label', default: 'FieldValue')] as Object[], "Another user has updated this FieldValue while you were editing")
                    render(view: "edit", model: [fieldValueInstance: fieldValueInstance])
                    return
                }
            }
            fieldValueInstance.properties = params
            if (!fieldValueInstance.hasErrors() && fieldValueInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), fieldValueInstance.id])}"
                redirect(action: "show", id: fieldValueInstance.id)
            }
            else {
                render(view: "edit", model: [fieldValueInstance: fieldValueInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def fieldValueInstance = FieldValue.get(params.id)
        if (fieldValueInstance) {
            try {
                fieldValueInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'fieldValue.label', default: 'FieldValue'), params.id])}"
            redirect(action: "list")
        }
    }
}
