package tfc.logs
import org.codehaus.groovy.grails.plugins.springsecurity.SpringSecurityUtils;
import grails.plugins.springsecurity.Secured

class LogsUploadController {
    def springSecurityService

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [logsUploadInstanceList: LogsUpload.list(params), logsUploadInstanceTotal: LogsUpload.count()]
    }

    def create = {
        def logsUploadInstance = new LogsUpload()
        logsUploadInstance.properties = params
        def user = springSecurityService.currentUser
        logsUploadInstance.person=user
        return [logsUploadInstance: logsUploadInstance]
    }

    def save = {
        def logsUploadInstance = new LogsUpload(params)
        if (logsUploadInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), logsUploadInstance.id])}"
            redirect(action: "show", id: logsUploadInstance.id)
        }
        else {
            render(view: "create", model: [logsUploadInstance: logsUploadInstance])
        }
    }

    def show = {
        def logsUploadInstance = LogsUpload.get(params.id)
        if (!logsUploadInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
            redirect(action: "list")
        }
        else {
            [logsUploadInstance: logsUploadInstance]
        }
    }

    def edit = {
        def logsUploadInstance = LogsUpload.get(params.id)
        if (!logsUploadInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [logsUploadInstance: logsUploadInstance]
        }
    }

    def update = {
        def logsUploadInstance = LogsUpload.get(params.id)
        if (logsUploadInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (logsUploadInstance.version > version) {
                    
                    logsUploadInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'logsUpload.label', default: 'LogsUpload')] as Object[], "Another user has updated this LogsUpload while you were editing")
                    render(view: "edit", model: [logsUploadInstance: logsUploadInstance])
                    return
                }
            }
            logsUploadInstance.properties = params
            if (!logsUploadInstance.hasErrors() && logsUploadInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), logsUploadInstance.id])}"
                redirect(action: "show", id: logsUploadInstance.id)
            }
            else {
                render(view: "edit", model: [logsUploadInstance: logsUploadInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def logsUploadInstance = LogsUpload.get(params.id)
        if (logsUploadInstance) {
            try {
                logsUploadInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUpload.label', default: 'LogsUpload'), params.id])}"
            redirect(action: "list")
        }
    }


    def report = {
      println 'id->' + params.id
		redirect(uri:"${createLinkTo(dir:'../jasper')}" + "?_format=PDF&LOG=${params.id}&_name=Ficha_Log&_file=LogsDetail")
    }

}
