package tfc.logs
import org.codehaus.groovy.grails.plugins.springsecurity.SpringSecurityUtils;
import grails.plugins.springsecurity.Secured

class LogsUploadFilesController {
    def springSecurityService
    def ProcessLogUploadService
    def logToXMLService

    static transactional = true

    static allowedMethods = [save: "POST", update: "POST", delete: "GET"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [logsUploadFilesInstanceList: LogsUploadFiles.list(params), logsUploadFilesInstanceTotal: LogsUploadFiles.count()]
    }

    def create = {
        def logsUploadFilesInstance = new LogsUploadFiles()
        logsUploadFilesInstance.properties = params
        def user = springSecurityService.currentUser
        logsUploadFilesInstance.person=user

        return [logsUploadFilesInstance: logsUploadFilesInstance]
    }

    def save = {
        def miError=false
        def codError = 0
        def logsUploadFilesInstance = new LogsUploadFiles(params)
        def f = request.getFile('fileUpload')
        def nombre = f.getOriginalFilename()
        def tamano = nombre.size()
        def comienzo = tamano-3
        def extension
        def vacio = false

        if (comienzo>0){
          extension= nombre[comienzo..tamano-1]
        }else{
          miError=true
          codError = 4
        }

        if (extension!='log' && !miError && comienzo>0 ){
          miError=true
          codError = 1
        }

        logsUploadFilesInstance.logsUploadFilesName=f.getOriginalFilename()

        def criteria = LogsUploadFiles.createCriteria()

        def logs = criteria.list{
            eq "logsUpload.id", logsUploadFilesInstance.logsUpload.id
        }

        if (logs.empty){
          vacio=true
        }

        if (!miError){
            logs.each {
                  def logsUploadFilesOldInstance = it
                  if (logsUploadFilesOldInstance) {
                      try {
                          if (!vacio)
                            logsUploadFilesOldInstance.delete(flush: true)
                          def file = new File( grailsApplication.config.images.location.toString() + File.separatorChar + logsUploadFilesOldInstance.logsUploadFilesName )
                          file.delete()
                      }
                      catch (org.springframework.dao.DataIntegrityViolationException e) {
                           miError=true
                           codError=3
                      }
                  }
            }

            //insertamos grabamos el nuevo archivo
            if (logsUploadFilesInstance.save(flush: true)) {
              println 'fichero->' + f
                if(!f.empty) {
                  new File( grailsApplication.config.images.location.toString() ).mkdirs()
                  f.transferTo( new File( grailsApplication.config.images.location.toString() + File.separatorChar + f.getOriginalFilename() ) )
                  def resultProcess = ProcessLogUploadService.loadFile(logsUploadFilesInstance.id)
                  if (resultProcess!=0){
                      miError=true
                      codError=resultProcess
                  }
                }
                else {
                      miError=true
                      codError=4
                }
            }
            else{
                      miError=true
                      codError=2
            }
        }
                switch (codError){
                  case 0:
                    flash.message = 'El archivo ha sido registrado y procesado correctamente.'
                    redirect(controller:'logsUploadFiles', action: "show", id: logsUploadFilesInstance.id)
                    break;
                  case 1:
                    flash.errors = 'Lo sentimos, la extensión del archivo no permite su procesamiento. Solo se adminten extensiones .log.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 2:
                    flash.errors = 'Lo sentimos, este archivo ya se encuentra subido a la aplicación, y asociado a otro registro.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 3:
                    flash.errors = 'Lo sentimos, no se ha podido borrar el archivo anterior. Contacte con el administrador de la aplicación.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 4:
                    flash.errors = 'El campo fichero no puede estar en blanco. Por favor, seleccione un archivo con extensión .log.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 5:
                    flash.errors = 'No se ha podido cargar el contenido del archivo. Compruebe que su estructura correspoende a la de la plantilla seleccionada.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 6:
                    flash.errors = 'Lo sentimos, no se ha podido registrar el archivo correctamente.'
                    redirect(controller:'logsUpload', action: "show", id: logsUploadFilesInstance.logsUpload.id)
                    break;
                  case 7:
                    flash.errors = ' Lo sentimos, la estructura del archivo no corresponde a la de la plantilla seleccionada.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 8:
                    flash.errors = ' Lo sentimos, la estructura o contenido del archivo no corresponde a la de la plantilla seleccionada.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;
                  case 9:
                    flash.errors = ' Lo sentimos, por algún problema con el contenido, no se puede procesar el archivo.'
                    redirect(controller:'logsUploadFiles', action: "create", params:['logsUpload.id':  logsUploadFilesInstance.logsUpload.id])
                    break;

                }

    }

    def show = {
        def logsUploadFilesInstance = LogsUploadFiles.get(params.id)
        if (!logsUploadFilesInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
            redirect(action: "list")
        }
        else {
            [logsUploadFilesInstance: logsUploadFilesInstance]
        }
    }

    def edit = {
        def logsUploadFilesInstance = LogsUploadFiles.get(params.id)
        if (!logsUploadFilesInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [logsUploadFilesInstance: logsUploadFilesInstance]
        }
    }

    def update = {
        def logsUploadFilesInstance = LogsUploadFiles.get(params.id)

        if (logsUploadFilesInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (logsUploadFilesInstance.version > version) {
                    
                    logsUploadFilesInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles')] as Object[], "Another user has updated this LogsUploadFiles while you were editing")
                    render(view: "edit", model: [logsUploadFilesInstance: logsUploadFilesInstance])
                    return
                }
            }
            logsUploadFilesInstance.properties = params
            if (!logsUploadFilesInstance.hasErrors() && logsUploadFilesInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), logsUploadFilesInstance.id])}"
                redirect(action: "show", id: logsUploadFilesInstance.id)
            }
            else {
                render(view: "edit", model: [logsUploadFilesInstance: logsUploadFilesInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def logsUploadFilesInstance = LogsUploadFiles.get(params.id)
        if (logsUploadFilesInstance) {
            try {
                logsUploadFilesInstance.delete(flush: true)
                def file = new File( grailsApplication.config.images.location.toString() + File.separatorChar + logsUploadFilesInstance.logsUploadFilesName )
		        file.delete()
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
                //redirect(action: "list")
              redirect(controller:'logsUpload', action: "show", id: logsUploadFilesInstance.logsUpload.id)
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'logsUploadFiles.label', default: 'LogsUploadFiles'), params.id])}"
            //redirect(action: "list")
          redirect(controller:'logsUpload', action: "show", id: logsUploadFilesInstance.logsUpload.id)
        }
    }

    def uploadFile = {

        try {
          def processLogUploadService = new ProcessLogUploadService ()
            processLogUploadService.loadFile(params.id)
            flash.message = "Archivo procesado correctamente"
        }catch(e){
            flash.message = "Error al procesar el archivo. Excepción capturada: " + e
            println "Error en procesado de log" + e
        }
      redirect action:"show", id:params.id

    }

    def log2XML = {
        try {

            def string = logToXMLService.generateXML(params.id)
            flash.message = "XML Generado correctamente"
            response.setHeader("Content-disposition", "attachment; filename=Log2XML.xml");
            render(contentType:"text/xml",encoding:"UTF-8", text: string.toString())
        }catch(e){
            flash.message = "Error al gnerar el XML. Excepción capturada: " + e
        }
    }

    def download = {

        def xmlFile= new FileInputStream("web-app/logFiles/" + params.fileName)

        response.contentType = "application/octet-stream"
        response.setHeader("Content-disposition", "attachment; filename="+params.fileName);
        response.outputStream << xmlFile

    }

    def downloadXMLSchema = {

        def xmlFile= new FileInputStream("schema/schema.xsd")

        response.contentType = "application/octet-stream"
        response.setHeader("Content-disposition", "attachment; filename=schema.xsd");
        response.outputStream << xmlFile

    }

    def manual = {

        def pdfFile= new FileInputStream("manual.pdf")

        response.contentType = "application/octet-stream"
        response.setHeader("Content-disposition", "attachment; filename=Manual.pdf");
        response.outputStream << pdfFile

    }


  	def upload = {
		def f = request.getFile('fileUpload')
	    if(!f.empty) {
	      flash.message = 'Your file has been uploaded'
		  new File( grailsApplication.config.images.location.toString() ).mkdirs()
		  f.transferTo( new File( grailsApplication.config.images.location.toString() + File.separatorChar + f.getOriginalFilename() ) )
		}
	    else {
	       flash.message = 'file cannot be empty'
	    }
		//redirect( action:list)
	}
}
