package tfc.logs
import org.codehaus.groovy.grails.plugins.springsecurity.SpringSecurityUtils;
import grails.plugins.springsecurity.Secured

class ThemeController {
  def springSecurityService

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [themeInstanceList: Theme.list(params), themeInstanceTotal: Theme.count()]
    }

    def create = {
        def themeInstance = new Theme()
        themeInstance.properties = params
        def user = springSecurityService.currentUser
        themeInstance.person=user

        return [themeInstance: themeInstance]
    }

    def save = {
        def themeInstance = new Theme(params)
        if (themeInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'theme.label', default: 'Theme'), themeInstance.id])}"
            redirect(action: "show", id: themeInstance.id)
        }
        else {
            render(view: "create", model: [themeInstance: themeInstance])
        }
    }

    def show = {
        def themeInstance = Theme.get(params.id)
        if (!themeInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
            redirect(action: "list")
        }
        else {
            [themeInstance: themeInstance]
        }
    }

    def edit = {
        def themeInstance = Theme.get(params.id)
        if (!themeInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [themeInstance: themeInstance]
        }
    }

    def update = {
        def themeInstance = Theme.get(params.id)
        if (themeInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (themeInstance.version > version) {
                    
                    themeInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'theme.label', default: 'Theme')] as Object[], "Another user has updated this Theme while you were editing")
                    render(view: "edit", model: [themeInstance: themeInstance])
                    return
                }
            }
            themeInstance.properties = params
            if (!themeInstance.hasErrors() && themeInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'theme.label', default: 'Theme'), themeInstance.id])}"
                redirect(action: "show", id: themeInstance.id)
            }
            else {
                render(view: "edit", model: [themeInstance: themeInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def themeInstance = Theme.get(params.id)
        if (themeInstance) {
            try {
                themeInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'theme.label', default: 'Theme'), params.id])}"
            redirect(action: "list")
        }
    }
}
