package tfc.secure

class PersonAuthorityController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [personAuthorityInstanceList: PersonAuthority.list(params), personAuthorityInstanceTotal: PersonAuthority.count()]
    }

    def create = {
        def personAuthorityInstance = new PersonAuthority()
        personAuthorityInstance.properties = params
        return [personAuthorityInstance: personAuthorityInstance]
    }

    def save = {
        def personAuthorityInstance = new PersonAuthority(params)
        if (personAuthorityInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), personAuthorityInstance.id])}"
            redirect(action: "show", id: personAuthorityInstance.id)
        }
        else {
            render(view: "create", model: [personAuthorityInstance: personAuthorityInstance])
        }
    }

    def show = {
        def personAuthorityInstance = PersonAuthority.get(params.id)
        if (!personAuthorityInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
            redirect(action: "list")
        }
        else {
            [personAuthorityInstance: personAuthorityInstance]
        }
    }

    def edit = {
        def personAuthorityInstance = PersonAuthority.get(params.id)
        if (!personAuthorityInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [personAuthorityInstance: personAuthorityInstance]
        }
    }

    def update = {
        def personAuthorityInstance = PersonAuthority.get(params.id)
        if (personAuthorityInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (personAuthorityInstance.version > version) {
                    
                    personAuthorityInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'personAuthority.label', default: 'PersonAuthority')] as Object[], "Another user has updated this PersonAuthority while you were editing")
                    render(view: "edit", model: [personAuthorityInstance: personAuthorityInstance])
                    return
                }
            }
            personAuthorityInstance.properties = params
            if (!personAuthorityInstance.hasErrors() && personAuthorityInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), personAuthorityInstance.id])}"
                redirect(action: "show", id: personAuthorityInstance.id)
            }
            else {
                render(view: "edit", model: [personAuthorityInstance: personAuthorityInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def personAuthorityInstance = PersonAuthority.get(params.id)
        if (personAuthorityInstance) {
            try {
                personAuthorityInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'personAuthority.label', default: 'PersonAuthority'), params.id])}"
            redirect(action: "list")
        }
    }
}
