package tfc.secure

import tfc.logs.Theme
import tfc.logs.Template
import tfc.logs.LogsUpload

class Person {

	transient springSecurityService

	String username
	String password
    String name
	boolean enabled
	boolean accountExpired
	boolean accountLocked
	boolean passwordExpired

    String toString(){
      return name
    }

	static constraints = {
		username blank: false, unique: true
		password blank: false
        name blank: false, nullable: false
	}

    static hasMany = [template:Template, theme:Theme, logsUpload:LogsUpload, personAuthority:PersonAuthority]

    static belongsTo = [userGroup: UserGroup]

	static mapping = {
		password column: '`password`'
	}

	Set<Authority> getAuthorities() {
		PersonAuthority.findAllByPerson(this).collect { it.authority } as Set
	}

	def beforeInsert() {
		encodePassword()
	}

	def beforeUpdate() {
		if (isDirty('password')) {
			encodePassword()
		}
	}

	protected void encodePassword() {
		password = springSecurityService.encodePassword(password)
	}
}
